@@ -10,8 +10,8 @@ from mozprofile.permissions import ServerLocations
 from mozrunner import FirefoxRunner
 
 from .base import get_free_port, Browser, ExecutorBrowser, require_arg, cmd_arg
-from ..executors import get_executor_kwargs
-from ..executors.executormarionette import MarionetteTestharnessExecutor, MarionetteReftestExecutor
+from ..executors import get_executor_kwargs as base_executor_kwargs
+from ..executors.executormarionette import MarionetteTestharnessExecutor, MarionetteReftestExecutor, required_files
 
 here = os.path.join(os.path.split(__file__)[0])
 
@@ -24,16 +24,27 @@ __wptrunner__ = {"product": "firefox",
                  "executor_kwargs": "get_executor_kwargs",
                  "env_options": "env_options"}
 
+
 def check_args(**kwargs):
     require_arg(kwargs, "binary")
 
+
 def browser_kwargs(**kwargs):
     return {"binary": kwargs["binary"],
             "prefs_root": kwargs["prefs_root"]}
 
+
+def get_executor_kwargs(http_server_url, **kwargs):
+    executor_kwargs = base_executor_kwargs(http_server_url, **kwargs)
+    executor_kwargs["close_after_done"] = True
+    return executor_kwargs
+
+
 def env_options():
     return {"host": "localhost",
-            "bind_hostname": "true"}
+            "bind_hostname": "true",
+            "required_files": required_files}
+
 
 class FirefoxBrowser(Browser):
     used_ports = set()
@@ -113,4 +124,3 @@ class FirefoxBrowser(Browser):
 
     def executor_browser(self):
         return ExecutorBrowser, {"marionette_port": self.marionette_port}
-
