@@ -1,25 +1,19 @@
-import socket
-import sys
-import os
-import uuid
-from collections import defaultdict
-import time
-import urlparse
-import threading
-import hashlib
-import traceback
 import json
-
-import marionette
-from mozprocess import ProcessHandler
+import os
 
 here = os.path.split(__file__)[0]
 
+
 def get_executor_kwargs(http_server_url, **kwargs):
+    timeout_multiplier = kwargs["timeout_multiplier"]
+    if timeout_multiplier is None:
+        timeout_multiplier = 1
+
     executor_kwargs = {"http_server_url": http_server_url,
-                       "timeout_multiplier":kwargs["timeout_multiplier"]}
+                       "timeout_multiplier": timeout_multiplier}
     return executor_kwargs
 
+
 class TestharnessResultConverter(object):
     harness_codes = {0: "OK",
                      1: "ERROR",
@@ -40,9 +34,11 @@ class TestharnessResultConverter(object):
                                          subtest["message"]) for subtest in result["tests"]])
 testharness_result_converter = TestharnessResultConverter()
 
+
 def reftest_result_converter(self, test, result):
     return (test.result_cls(result["status"], result["message"]), [])
 
+
 class TestExecutor(object):
     convert_result = None
 
@@ -76,3 +72,6 @@ class TestExecutor(object):
 
     def run_test(self):
         raise NotImplementedError
+
+    def after_result(self):
+        pass
